summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorIulian Dragos <jaguarul@gmail.com>2011-10-11 09:58:13 +0000
committerIulian Dragos <jaguarul@gmail.com>2011-10-11 09:58:13 +0000
commit063f2c4984fc5047fd2909d7274cb9c62666c486 (patch)
tree521a8e221800dc89edd8b4e161049e0bef7b7de6
parentca47241bf8895d6c3a73a619c677bb6a2849a599 (diff)
downloadscala-063f2c4984fc5047fd2909d7274cb9c62666c486.tar.gz
scala-063f2c4984fc5047fd2909d7274cb9c62666c486.tar.bz2
scala-063f2c4984fc5047fd2909d7274cb9c62666c486.zip
Presentation compiler: let ShutdownReq propagat...
Presentation compiler: let ShutdownReq propagate from the background compiler, and don't mark a unit as crashed in that case.
-rw-r--r--src/compiler/scala/tools/nsc/interactive/Global.scala3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/compiler/scala/tools/nsc/interactive/Global.scala b/src/compiler/scala/tools/nsc/interactive/Global.scala
index 47c34b9968..ec364e237f 100644
--- a/src/compiler/scala/tools/nsc/interactive/Global.scala
+++ b/src/compiler/scala/tools/nsc/interactive/Global.scala
@@ -469,7 +469,8 @@ class Global(settings: Settings, reporter: Reporter, projectName: String = "")
r set unit.body
serviceParsedEntered()
} catch {
- case ex: FreshRunReq => throw ex // propagate a new run request
+ case ex: FreshRunReq => throw ex // propagate a new run request
+ case ShutdownReq => throw ShutdownReq // propagate a shutdown request
case ex =>
println("[%s]: exception during background compile: ".format(unit.source) + ex)